@@ -81,7 +81,7 @@ void KisToolCrop::activate(ToolActivation toolActivation, const QSet<KoShape*> &
     if(currentNode() && currentNode()->paintDevice()) {
         m_optWidget->cmbType->setEnabled(true);
     }
-    //shape layer
+    //vector layer
     else {
         m_optWidget->cmbType->setEnabled(false);
     }
@@ -93,6 +93,8 @@ void KisToolCrop::deactivate()
     m_rectCrop = QRect(0, 0, 0, 0);
     updateWidgetValues();
     updateCanvasPixelRect(image()->bounds());
+
+    KisTool::deactivate();
 }
 
 void KisToolCrop::resourceChanged(int key, const QVariant &res)
@@ -104,7 +106,7 @@ void KisToolCrop::resourceChanged(int key, const QVariant &res)
     if(currentNode() && currentNode()->paintDevice()) {
         m_optWidget->cmbType->setEnabled(true);
     }
-    //shape layer
+    //vector layer
     else {
         m_optWidget->cmbType->setCurrentIndex(1);
         m_optWidget->cmbType->setEnabled(false);
@@ -436,8 +438,6 @@ void KisToolCrop::paintOutlineWithHandles(QPainter& gc)
 
 void KisToolCrop::crop()
 {
-    // XXX: Should cropping be part of KisImage/KisPaintDevice's API?
-
     m_haveCropSelection = false;
     useCursor(cursor());
 
@@ -636,11 +636,6 @@ QWidget* KisToolCrop::createOptionWidget()
     return m_optWidget;
 }
 
-QWidget* KisToolCrop::optionWidget()
-{
-    return m_optWidget;
-}
-
 QRectF KisToolCrop::lowerRightHandleRect(QRectF cropBorderRect)
 {
     return QRectF(cropBorderRect.right() - m_handleSize / 2.0, cropBorderRect.bottom() - m_handleSize / 2.0, m_handleSize, m_handleSize);
