@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010-2011 Casper Boemann <cbo@boemann.dk>
+ * Copyright (C) 2010-2012 C. Boemann <cbo@boemann.dk>
  * Copyright (C) 2006,2011 Sebastian Sauer <mail@dipe.org>
  * Copyright (C) 2006-2007, 2010 Thomas Zander <zander@kde.org>
  *
@@ -317,32 +317,29 @@ void KWRootAreaProvider::releaseAllAfter(KoTextLayoutRootArea *afterThis)
 
     kDebug(32001) << "afterPageNumber=" << afterIndex+1;
 
-//     bool atLeastOnePageRemove = false;
-//     KWPageManager *pageManager = m_textFrameSet->wordsDocument()->pageManager();
+    bool atLeastOnePageRemoved = false;
+    KWPageManager *pageManager = m_textFrameSet->wordsDocument()->pageManager();
     if (afterIndex >= 0) {
         for(int i = m_pages.count() - 1; i > afterIndex; --i) {
             KWRootAreaPage *page = m_pages.takeLast();
             foreach(KoTextLayoutRootArea *area, page->rootAreas)
                 m_pageHash.remove(area);
             delete page;
-            /*
+
             if (m_textFrameSet->textFrameSetType() == Words::MainTextFrameSet) {
                 pageManager->removePage(i+1);
-                atLeastOnePageRemove = true;
+                atLeastOnePageRemoved = true;
             }
-            */
         }
 
-        /*FIXME
+        // FIXME
         for(int i = m_dependentProviders.count() - 1; i >= 0; --i) {
             QPair<KWRootAreaProvider *, int> p = m_dependentProviders[i];
             if (p.second >= afterIndex)
                 m_dependentProviders.removeAt(i);
         }
-        */
-
     } else {
-        //atLeastOnePageRemove = !m_pages.isEmpty();
+        //atLeastOnePageRemoved = !m_pages.isEmpty();
         qDeleteAll(m_pages);
         m_pages.clear();
         m_pageHash.clear();
@@ -356,8 +353,8 @@ void KWRootAreaProvider::releaseAllAfter(KoTextLayoutRootArea *afterThis)
         m_dependentProviders.clear();
         */
     }
-//     if (atLeastOnePageRemove)
-//         m_textFrameSet->wordsDocument()->firePageSetupChanged();
+     if (atLeastOnePageRemoved)
+         m_textFrameSet->wordsDocument()->firePageSetupChanged();
 }
 
 void KWRootAreaProvider::doPostLayout(KoTextLayoutRootArea *rootArea, bool isNewRootArea)
@@ -388,7 +385,9 @@ void KWRootAreaProvider::doPostLayout(KoTextLayoutRootArea *rootArea, bool isNew
     QRectF updateRect = rootArea->associatedShape()->outlineRect();
     //rootArea->associatedShape()->update(updateRect);
 
-    QSizeF newSize = rootArea->associatedShape()->size();
+    QSizeF newSize = rootArea->associatedShape()->size()
+                    - QSizeF(data->leftPadding() + data->rightPadding(),
+                             data->topPadding() + data->bottomPadding());
     if (isHeaderFooter
         ||data->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight
         ||data->resizeMethod() == KoTextShapeData::AutoGrowHeight) {
@@ -409,8 +408,12 @@ void KWRootAreaProvider::doPostLayout(KoTextLayoutRootArea *rootArea, bool isNew
     }
 
     // To make sure footnotes always end up at the bottom of the main area we need to set this
-    rootArea->setBottom(rootArea->top() + newSize.height());
+    if (m_textFrameSet->textFrameSetType() == Words::MainTextFrameSet) {
+        rootArea->setBottom(rootArea->top() + newSize.height());
+    }
 
+    newSize += QSizeF(data->leftPadding() + data->rightPadding(),
+                      data->topPadding() + data->bottomPadding());
     if (newSize != rootArea->associatedShape()->size()) {
         //QPointF centerpos = rootArea->associatedShape()->absolutePosition();
         rootArea->associatedShape()->setSize(newSize);
@@ -570,13 +573,15 @@ QSizeF KWRootAreaProvider::suggestSize(KoTextLayoutRootArea *rootArea)
     KoTextShapeData *data = qobject_cast<KoTextShapeData*>(shape->userData());
     Q_ASSERT(data);
 
-    if (data->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight || data->resizeMethod() == KoTextShapeData::AutoGrowHeight) {
-        QSizeF size = shape->size();
+    QSizeF size = shape->size() - QSizeF(data->leftPadding() + data->rightPadding(), data->topPadding() + data->bottomPadding());
+    size.setWidth(qMax(size.width(), qreal(1.0)));
+    size.setHeight(qMax(size.height(), qreal(1.0)));
+    if (data->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight || data->resizeMethod() == KoTextShapeData::AutoGrowHeight
+        || m_textFrameSet->textFrameSetType() == Words::OtherTextFrameSet) {
         size.setHeight(1E6);
-        return size;
     }
 
-    return shape->size();
+    return size;
 }
 
 QList<KoTextLayoutObstruction *> KWRootAreaProvider::relevantObstructions(KoTextLayoutRootArea *rootArea)
@@ -610,7 +615,7 @@ QList<KoTextLayoutObstruction *> KWRootAreaProvider::relevantObstructions(KoText
                 continue;
             if (! shape->isVisible(true))
                 continue;
-            if (frame->anchor()->anchorType() != KoTextAnchor::AnchorPage)
+            if (frame->anchorType() != KoTextAnchor::AnchorPage)
                 continue;
             if (shape->textRunAroundSide() == KoShape::RunThrough)
                 continue;
